##  Managing Impacts in the Transformations Explorer
You can edit custom impacts by opening the relevant fact sheet directly from the transformations explorer. To edit a custom impact, do the following:
  1. Choose Edit in the toolbar.
  2. In the Impacts column, choose the link (for example, 4 impacts) to open the impacts overlay. If the impacts column is not visible, you need to add it to the table. For more information, see [Customizing Table Columns in the Transformations Explorer](https://help.sap.com/docs/leanix/ea/transformations-explorer?locale=en-US&state=PRODUCTION&version=CLOUD#loio98623f7d5c9b44e5a42c787307e0a027__Customizing-Table-Columns-in-the-Transformations-Explorer)
  3. To access the initiative fact sheet, choose the link in the banner at the top of the overlay.
![How to Edit Custom Impacts](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3bbb68f66383487f9c2285bff18fea73_LowRes.png)
How to Edit Custom Impacts
  4. In the initiative, scroll to Custom impacts and choose Add to create or edit impacts.
